/*
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *  
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <string>
#include <sstream>
#include "Logger.hpp"
#include "Cd2isoException.hpp"

using namespace std;

Cd2isoException::Cd2isoException(const char* reason, const char* file, const int line, const int loglevel) throw()
{
    _reason = reason;
    _file = file;
    _line = line;
    _loglevel = loglevel;
    if(_loglevel == -1) _loglevel = Logger::DEBUG_LEVEL;
    try {
        Logger::get_instance().log(_loglevel, "Exception: " + string(_reason), _file, _line);
    }
    catch (exception& e) {
        // Failed to log the exception. No big deal...
    }
    _message = 0;
}

Cd2isoException::~Cd2isoException() throw()
{
    if(_message != 0) {
        delete _message;
        _message = 0;
    }
}

const char* Cd2isoException::what() throw()
{
    return _reason;
}
