/*
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "DeviceReader.h"

#include <windows.h>
#include <string>
#include "Logger.hpp"
#include "util.h"

using namespace std;

DeviceReader::DeviceReader(string driveLetter)
{
    LOG_DEBUG("DeviceReader::DeviceReader()");
    
	mFailed = false;
	string devicePath = "\\\\.\\" + driveLetter + ":";
	LOG_DEBUG("devicePath = '"+str(devicePath)+"'");
	
	LOG_DEBUG("Calling CreateFile()");
	mDeviceHandle = CreateFile(devicePath.c_str(), GENERIC_READ, FILE_SHARE_READ, NULL, OPEN_EXISTING, FILE_FLAG_SEQUENTIAL_SCAN, NULL);
	if (mDeviceHandle == INVALID_HANDLE_VALUE)
	{
		setError(get_lasterror());
		LOG_ERROR("CreateFile() failed! "+getError());
		return;
	}
}

DeviceReader::~DeviceReader()
{
    LOG_DEBUG("DeviceReader::~DeviceReader(). Closing handle to the CD device.");
	CloseHandle(mDeviceHandle);
}

bool DeviceReader::failed()
{
	return mFailed;
}

string DeviceReader::getError()
{
	return mError;
}

void DeviceReader::setError(string error)
{
	mError = error;
	mFailed = true;
}

string DeviceReader::read(int buflen)
{
	char buf[buflen];
	DWORD bytesRead = 0;
	if (!ReadFile(mDeviceHandle, buf, sizeof(buf), &bytesRead, NULL))
	{
		setError(get_lasterror());
		LOG_ERROR("ReadFile() failed! "+getError());
		return "";
	}
	return string(buf, bytesRead);
}

