/*
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *  
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <string>
#include <fstream>
#include <iostream>
#include <sys/stat.h>
#include "Cd2isoException.hpp"
#include "Logger.hpp"

using namespace std;

Logger& Logger::get_instance() 
{
    static Logger inst;
    return inst;
}

Logger::Logger()
{
    _filename = "log.txt";
    _level = 0;
    _console_level = INFO_LEVEL;
}

void Logger::set_file_name(std::string fileName)
{
    _filename = fileName;
}

void Logger::set_level(int level)
{
    _level = level;
}

void Logger::set_console_level(int level)
{
    _console_level = level;
}

void Logger::clear_log_file()
{
    // Check if the file exists
    struct stat filestat;
    if(stat(_filename.c_str(), &filestat) != 0) {
        return; // It doesn't exist, so there's no need to do anything.
    }
    // Clear the file
    ofstream outfile(_filename.c_str(), ofstream::out | ofstream::trunc);
    if(outfile.fail())
        THROW_EX("Failed to open file.");
    outfile.close();
}

void Logger::log(int level, std::string message, const char* file, int line)
{
    if(level < _level) return;

    string levelName = "UNKNOWN";
    if(level == 1) levelName = "DEBUG";
    if(level == 2) levelName = "INFO";
    if(level == 3) levelName = "WARNING";
    if(level == 4) levelName = "ERROR";

    if(level >= _console_level) {
        cout << "(" << levelName << "): " << message << endl;
    }

    ofstream outfile(_filename.c_str(), ofstream::out | ofstream::app | ofstream::binary);
    if(outfile.fail())
        THROW_EX("Failed to open file.");
    outfile << file << ":" << line << " (" << levelName << "): " << message << endl;
    if(outfile.bad())
        THROW_EX("Write operation failed.");
    outfile.close();
}
