#ifndef _LOGGER_H
#define _LOGGER_H

#include <string>

#define LOG_DEBUG(message) Logger::get_instance().log(Logger::DEBUG_LEVEL,   message, __FILE__, __LINE__);
#define LOG_INFO(message) Logger::get_instance().log(Logger::INFO_LEVEL,    message, __FILE__, __LINE__);
#define LOG_WARNING(message) Logger::get_instance().log(Logger::WARNING_LEVEL, message, __FILE__, __LINE__);
#define LOG_ERROR(message) Logger::get_instance().log(Logger::ERROR_LEVEL,   message, __FILE__, __LINE__);

class Logger 
{
    public:
        static Logger& get_instance();
        void log(int level, std::string message, const char* file = "Unknown file", int line = -1);
        void set_file_name(std::string fileName);
        void set_level(int level);
        void set_console_level(int level);
        void clear_log_file();
        static const int DEBUG_LEVEL   = 1; // Uninteresting debug messages.
        static const int INFO_LEVEL    = 2; // Useful information.
        static const int WARNING_LEVEL = 3; // Things that might be a problem.
        static const int ERROR_LEVEL   = 4; // Things that are clearly a problem.
        static const int NONE_LEVEL    = 5; // Used to disable logging.
    private:
        Logger();
        Logger(const Logger&);
        Logger& operator= (const Logger&);
        std::string _filename; // Logfile to save messages to.
        int _level; // Messages of lower level than this are ignored.
        int _console_level; // Messages of lower level than this or _level won't be written to stdout.
};

#endif

