/*
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <windows.h>
#include <iostream>
#include <string>
#include "Logger.hpp"
#include "ImgCreator.h"

using namespace std;

int main(int argc, const char* argv[])
{
    bool result = true;
    cout << "CD2ISO TEST version 1" << endl;
    cout << "An attempt to solve Wubi Bug #207137" << endl;
    cout << "See https://bugs.launchpad.net/wubi/+bug/207137" << endl << endl;
    // Checking arguments
    if(argc != 2) {
        cout << "Wrong number of arguments." << endl << endl;
        cout << "Usage:" << endl;
        cout << "  cd2iso.exe DRIVE-LETTER" << endl;
        cout << "  where DRIVE-LETTER is the CD drive letter (eg D)." << endl;
        return EXIT_FAILURE;
    }
    // Settings
    string fileNameIn = argv[1];
    string fileNameOut = "cd2iso_test.iso";
    // Init logging
    try {
        Logger &log = Logger::get_instance();
        log.set_file_name("cd2iso-log.txt");
        log.set_level(Logger::DEBUG_LEVEL);
        log.set_console_level(Logger::INFO_LEVEL);
        log.clear_log_file();
        LOG_DEBUG("Started logging...");
    }
    catch(exception &e) {
        cout << "Failed to initialize the logger!" << endl;
        return EXIT_FAILURE;
    }
    // Create image
    
    try {
        LOG_DEBUG("Creating ImgCreator instance.");
        ImgCreator img;
        LOG_DEBUG("Calling ImgCreator::createImg()");
        result = img.createImg(fileNameIn, fileNameOut);
        if(result) {
            LOG_INFO("Sucessfully created iso.");
            LOG_INFO("Deleting the created iso file.");
            DeleteFile(fileNameOut.c_str());
        } else {
            LOG_ERROR("Failed to created iso!");
        }
    }
    catch(exception &e) {
        LOG_ERROR("Uncaught exception!");
        result = false;
    }
    // Print some instructions
    cout << endl;
    cout << "A log file called cd2iso-log.txt has been created in the current" << endl;
    cout << "working directory." << endl << endl;
    if(result) {
        cout << "This worked excellently on your computer! Unfortunately this" << endl;
        cout << "means that your log probably isn't that interesting..." << endl << endl;
        cout << "If you are interested in this bug, you can find out more here:" << endl;
        cout << "  https://bugs.launchpad.net/wubi/+bug/207137" << endl << endl;
        cout << "Thank you for your participation!" << endl;
    } else {
        cout << "Something went wrong, which means that your log file could be" << endl;
        cout << "really useful!" << endl << endl;
        cout << "Please consider writing a comment, with your log attached, here:" << endl;
        cout << "  https://bugs.launchpad.net/wubi/+bug/207137" << endl << endl;
        cout << "Thanks in advance!" << endl;
    }
    // Exit
    if(result) {
        return EXIT_SUCCESS;
    } else {
        return EXIT_FAILURE;
    }
}
